@@ -19,9 +19,9 @@
 
 """Provides a SpeechServer factory for gnome-speech drivers."""
 
-__id__        = "$Id: gnomespeechfactory.py 4336 2008-11-17 18:15:32Z wwalker $"
-__version__   = "$Revision: 4336 $"
-__date__      = "$Date: 2008-11-17 13:15:32 -0500 (Mon, 17 Nov 2008) $"
+__id__        = "$Id: gnomespeechfactory.py 4453 2009-01-22 00:35:18Z wwalker $"
+__version__   = "$Revision: 4453 $"
+__date__      = "$Date: 2009-01-21 19:35:18 -0500 (Wed, 21 Jan 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -705,7 +705,10 @@ class SpeechServer(speechserver.SpeechServer):
                      used to augment/override the default
                      voice settings.
         """
-        self.speak(chnames.getCharacterName(character), acss)
+        chname = chnames.getCharacterName(character)
+        if orca_state.activeScript and orca_state.usePronunciationDictionary:
+            chname = orca_state.activeScript.adjustForPronunciation(chname)
+        self.speak(chname, acss)
 
     def speakUtterances(self, utterances, acss=None, interrupt=True):
         """Speaks the given list of utterances immediately.
@@ -894,8 +897,6 @@ class SpeechServer(speechserver.SpeechServer):
             return -1
 
         text = self.__addVerbalizedPunctuation(text)
-        if orca_state.activeScript and orca_state.usePronunciationDictionary:
-            text = orca_state.activeScript.adjustForPronunciation(text)
 
         try:
             # [[[TODO: WDW - back this stop out for now.  The problem is
