@@ -20,9 +20,9 @@
 """Uses speech prompts and a command line interface to set Orca
 user preferences."""
 
-__id__        = "$Id: orca_console_prefs.py 4049 2008-07-19 21:01:34Z wwalker $"
-__version__   = "$Revision: 4049 $"
-__date__      = "$Date: 2008-07-19 17:01:34 -0400 (Sat, 19 Jul 2008) $"
+__id__        = "$Id: orca_console_prefs.py 4462 2009-01-23 17:20:35Z wwalker $"
+__version__   = "$Revision: 4462 $"
+__date__      = "$Date: 2009-01-23 12:20:35 -0500 (Fri, 23 Jan 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -464,6 +464,17 @@ def showPreferencesUI(commandLineSettings):
                          speechVoiceChoice)
     prefsDict["enableBrailleMonitor"] = checkYes(answer)
 
+    # Translators: orca can be set up to automatically start when the 
+    # user logs in.
+    #
+    answer = sayAndPrint(_("Automatically start orca when you log in?  " \
+                           "Enter y or n: "),
+                         True,
+                         True,
+                         speechServerChoice,
+                         speechVoiceChoice)
+    settings.setOrcaAutostart(checkYes(answer))
+
     logoutNeeded = orca_prefs.writePreferences(prefsDict)
     if logoutNeeded:
         sayAndPrint(_("Accessibility support for GNOME has just been enabled."),
