@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "2.25.5"
+version     = "2.25.90"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/usr"
+prefix      = "/export/home/wwalker/work/orca/trunk/bld"
 
 # The package name (should be "orca").
 #
