@@ -23,13 +23,12 @@ implementation in Gecko:
 http://developer.mozilla.org/en/docs/Accessibility/ATSPI_Support
 """
 
-__id__        = "$Id: speech_generator.py 4399 2009-01-02 21:02:45Z joanied $"
-__version__   = "$Revision: 4399 $"
-__date__      = "$Date: 2009-01-02 21:02:45 +0000 (Fri, 02 Jan 2009) $"
+__id__        = "$Id: speech_generator.py 4474 2009-01-29 22:02:01Z wwalker $"
+__version__   = "$Revision: 4474 $"
+__date__      = "$Date: 2009-01-29 17:02:01 -0500 (Thu, 29 Jan 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import math
 import pyatspi
 
 import orca.rolenames as rolenames
@@ -38,7 +37,7 @@ import orca.speechgenerator as speechgenerator
 
 from orca.orca_i18n import _
 from orca.orca_i18n import ngettext # for ngettext support
-from orca.orca_i18n import Q_       # to provide qualified translatable strings
+from orca.orca_i18n import C_       # to provide qualified translatable strings
 
 ########################################################################
 #                                                                      #
@@ -542,16 +541,12 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
             # Translators: this is in reference to a radio button being
             # selected or not.
             #
-            # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
-            #
-            selectionState = Q_("radiobutton|selected")
+            selectionState = C_("radiobutton", "selected")
         else:
             # Translators: this is in reference to a radio button being
             # selected or not.
             #
-            # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
-            #
-            selectionState = Q_("radiobutton|not selected")
+            selectionState = C_("radiobutton", "not selected")
 
         if not already_focused:
             # The label is handled as a context in default.py -- assuming we
@@ -764,40 +759,7 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
             return speechgenerator.SpeechGenerator.\
                        _getSpeechForSlider(self, obj, already_focused)
 
-        value = obj.queryValue()
-
-        # OK, this craziness is all about trying to figure out the most
-        # meaningful formatting string for the floating point values.
-        # The number of places to the right of the decimal point should
-        # be set by the minimumIncrement, but the minimumIncrement isn't
-        # always set.  So...we'll default the minimumIncrement to 1/100
-        # of the range.  But, if max == min, then we'll just go for showing
-        # them off to two meaningful digits.
-        #
-        try:
-            minimumIncrement = value.minimumIncrement
-        except:
-            minimumIncrement = 0.0
-
-        if minimumIncrement == 0.0:
-            minimumIncrement = (value.maximumValue - value.minimumValue) \
-                               / 100.0
-
-        try:
-            decimalPlaces = max(0, -math.log10(minimumIncrement))
-        except:
-            try:
-                decimalPlaces = max(0, -math.log10(value.minimumValue))
-            except:
-                try:
-                    decimalPlaces = max(0, -math.log10(value.maximumValue))
-                except:
-                    decimalPlaces = 0
-
-        formatter = "%%.%df" % decimalPlaces
-        valueString = formatter % value.currentValue
-        #minString   = formatter % value.minimumValue
-        #maxString   = formatter % value.maximumValue
+        valueString = self._script.getTextForValue(obj)
 
         if already_focused:
             utterances = [valueString]
