@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 4383 2008-12-06 21:29:39Z joanied $"
-__version__   = "$Revision: 4383 $"
-__date__      = "$Date: 2008-12-06 16:29:39 -0500 (Sat, 06 Dec 2008) $"
+__id__        = "$Id: settings.py 4471 2009-01-28 17:52:43Z wwalker $"
+__version__   = "$Revision: 4471 $"
+__date__      = "$Date: 2009-01-28 12:52:43 -0500 (Wed, 28 Jan 2009) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -82,7 +82,7 @@ import pyatspi
 import debug
 from acss import ACSS
 from orca_i18n import _           # for gettext support
-from orca_i18n import Q_          # to provide qualified translatable strings
+from orca_i18n import C_          # to provide qualified translatable strings
 
 # These are the settings that Orca supports the user customizing.
 #
@@ -105,6 +105,7 @@ userCustomizableSettings = [
     "enableActionKeys",
     "enableNavigationKeys",
     "enableTutorialMessages",
+    "enableMnemonicSpeaking",
     "enableBraille",
     "enableBrailleContext",
     "enableBrailleGrouping",
@@ -161,6 +162,7 @@ userCustomizableSettings = [
     "sayAllStyle",
     "keyboardLayout",
     "speakBlankLines",
+    "speakMultiCaseStringsAsWords",
     "enabledSpokenTextAttributes",
     "enabledBrailledTextAttributes",
     "textAttributesBrailleIndicator",
@@ -574,9 +576,14 @@ enableActionKeys        = True
 #
 enableNavigationKeys    = False
 
-# If True, roles that have tutorial strings defined will be spoken.
+# If True, tutorial strings defined will be spoken.
+#
 enableTutorialMessages = False
 
+# If True, mnemonics will be spoken.
+#
+enableMnemonicSpeaking = False
+
 # If True, show the main Orca window.
 #
 showMainWindow          = True
@@ -623,6 +630,10 @@ outlineStyle = OUTLINE_BOX
 #
 speakBlankLines         = True
 
+# if True, process multi case strings as words.
+#
+speakMultiCaseStringsAsWords = False
+
 # If True, reads all the table cells in the current row rather than just
 # the current one.
 #
@@ -645,17 +656,13 @@ presentReadOnlyText = True
 # Translators: this is used to indicate the user is in a text
 # area that is not editable.  It is meant to be spoken to the user.
 #
-# ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
-#
-speechReadOnlyString = Q_("text|read only")
+speechReadOnlyString = C_("text", "read only")
 
 # Translators: this is used to indicate the user is in a text
 # area that is not editable.  It is meant to be a short abbreviation
 # to be presented on the braille display.
 #
-# ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
-#
-brailleReadOnlyString = Q_("text|rdonly")
+brailleReadOnlyString = C_("text", "rdonly")
 
 # The complete list of possible text attributes.
 #
