@@ -31,9 +31,9 @@
 NOTE: THIS IS EXPERIMENTAL ONLY AND IS NOT A SUPPORTED COMPONENT OF ORCA.
 """
 
-__id__ = "$Id: speechdispatcherfactory.py 4374 2008-12-01 19:18:32Z wwalker $"
-__version__   = "$Revision: 4374 $"
-__date__      = "$Date: 2008-12-01 14:18:32 -0500 (Mon, 01 Dec 2008) $"
+__id__ = "$Id: speechdispatcherfactory.py 4433 2009-01-19 15:46:14Z wwalker $"
+__version__   = "$Revision: 4433 $"
+__date__      = "$Date: 2009-01-19 10:46:14 -0500 (Mon, 19 Jan 2009) $"
 __author__    = "Tomas Cerha <cerha@brailcom.org>"
 __copyright__ = "Copyright (c) 2006-2008 Brailcom, o.p.s."
 __license__   = "LGPL"
@@ -44,7 +44,6 @@ import debug
 import speechserver
 import settings
 import orca
-import orca_state
 from acss import ACSS
 from orca_i18n import _
 
@@ -327,8 +326,7 @@ class SpeechServer(speechserver.SpeechServer):
     def speak(self, text=None, acss=None, interrupt=True):
         #if interrupt:
         #    self._cancel()
-        if orca_state.activeScript and orca_state.usePronunciationDictionary:
-            text = orca_state.activeScript.adjustForPronunciation(text)
+
         if text:
             self._speak(text, acss)
 
